@@ -110,7 +110,7 @@ bool collection<C>::iterator::operator== (const iterator& other) const
 {
   return impl_ == other.impl_
     || (!impl_ && other.impl_->ended_)
-    || (impl_->ended_ && !other.impl_);
+    || (impl_ && impl_->ended_ && !other.impl_);
 }
 
 template <class C>
@@ -229,6 +229,15 @@ collection<C>::const_iterator::operator= (const const_iterator& other)
   return *this;
 }
 
+template <class C>
+typename collection<C>::const_iterator&
+collection<C>::const_iterator::operator= (const iterator& other)
+{
+  impl_ = other;
+
+  return *this;
+}
+
 template <class C>
 C
 collection<C>::const_iterator::operator* ()
@@ -522,11 +531,11 @@ typename collection<C>::size_type collection<C>::size() const
     }
 
     if (type_ != QueryCollection) {
-      result += manualModeInsertions_.size();
-      result -= manualModeRemovals_.size();
+      result += static_cast<int>(manualModeInsertions_.size());
+      result -= static_cast<int>(manualModeRemovals_.size());
     }
 
-    return result;
+    return static_cast<typename collection<C>::size_type>(result);
   } else
     return 0;
 }
@@ -688,13 +697,13 @@ int collection<C>::count(C c) const
 
   Query<C, DynamicBinding> q = find().where(mapping->idCondition);
   c.obj()->bindId(q.parameters_);
-  int result = q.resultList().size();
+  std::size_t result = q.resultList().size();
 
   result += 
     std::count(manualModeInsertions_.begin(), manualModeInsertions_.end(), c);
   result -=
     std::count(manualModeRemovals_.begin(), manualModeRemovals_.end(), c);
-  return result;
+  return static_cast<int>(result);
 }
 
 template <class C>
