@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -156,13 +156,30 @@ public:
    */
   void setLayout(std::unique_ptr<WLayout> layout);
 
+  /*! \brief Sets a layout manager for the container, returning a raw pointer.
+   *
+   * This is implemented as:
+   *
+   * \code
+   * Layout *result = layout.get();
+   * setLayout(std::unique_ptr<WLayout>(std::move(layout)));
+   * return result;
+   * \endcode
+   *
+   * This is a useful shorthand that allows to create a layout and get a raw
+   * pointer to it in one line.
+   */
   template <typename Layout>
     Layout *setLayout(std::unique_ptr<Layout> layout)
+#ifndef WT_TARGET_JAVA
   {
     Layout *result = layout.get();
     setLayout(std::unique_ptr<WLayout>(std::move(layout)));
     return result;
   }
+#else // WT_TARGET_JAVA
+  ;
+#endif // WT_TARGET_JAVA
 
   /*! \brief Returns the layout manager that was set for the container.
    *
@@ -203,22 +220,19 @@ public:
    */
   template <typename Widget>
     Widget *addWidget(std::unique_ptr<Widget> widget)
+#ifndef WT_TARGET_JAVA
   {
     Widget *result = widget.get();
     addWidget(std::unique_ptr<WWidget>(std::move(widget)));
     return result;
   }
+#else // WT_TARGET_JAVA
+  ;
+#endif // WT_TARGET_JAVA
+
+#ifndef WT_TARGET_JAVA
 
   /*! \brief Creates a widget and adds it, returning a reference to it.
-   *
-   * This is implemented as:
-   *
-   * \code
-   * std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
-   * Widget *result = w.get();
-   * addWidget(std::unique_ptr<WWidget>{std::move(w)});
-   * return result;
-   * \endcode
    *
    * This is a useful shorthand for adding a new widget to the container, and
    * getting a reference to it, e.g.:
@@ -227,15 +241,55 @@ public:
    * Wt::WPushButton *button = container->addNew<Wt::WPushButton>("Click me!");
    * // do something with button, including safely using it in a lambda function
    * \endcode
+   *
+   * The implementation is equivalent to the following code:
+   *
+   * \code
+   * std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
+   * Widget *result = w.get();
+   * addWidget(std::unique_ptr<WWidget>{std::move(w)});
+   * return result;
+   * \endcode
+   *
+   * There's an exception for global widgets, like WPopupWidget. In this case
+   * the implementation is equivalent to:
+   *
+   * \code
+   * std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
+   * Widget *result = w.get();
+   * addChild(std::unique_ptr<WObject>(std::move(w)));
+   * return result;
+   * \endcode
+   *
+   * Since popup widgets (and similar widgets) are always and automatically placed
+   * in a global location in the widget tree, only their ownership is transferred.
    */
   template <typename Widget, typename ...Args>
-    Widget *addNew( Args&& ...args )
+  Widget *addNew( Args&& ...args )
   {
     std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
     Widget *result = w.get();
-    addWidget(std::unique_ptr<WWidget>{std::move(w)});
+    if (w->isGlobalWidget()) {
+      addChild(std::unique_ptr<WObject>{std::move(w)});
+    } else {
+      addWidget(std::unique_ptr<WWidget>{std::move(w)});
+    }
     return result;
   }
+#else // WT_TARGET_JAVA
+  template <typename Widget>
+    Widget *addNew();
+  template <typename Widget, typename Arg1>
+    Widget *addNew(Arg1 arg1);
+  template <typename Widget, typename Arg1, typename Arg2>
+    Widget *addNew(Arg1 arg1, Arg2 arg2);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3, typename Arg4>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3, typename Arg4, typename Arg5>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5);
+#endif // WT_TARGET_JAVA
 
   /*! \brief Inserts a child widget in this container, before another
    *         widget.
@@ -263,11 +317,15 @@ public:
    */
   template <typename Widget>
     Widget *insertBefore(std::unique_ptr<Widget> widget, WWidget *before)
+#ifndef WT_TARGET_JAVA
   {
     Widget *result = widget.get();
     insertBefore(std::unique_ptr<WWidget>(std::move(widget)), before);
     return result;
   }
+#else // WT_TARGET_JAVA
+  ;
+#endif // WT_TARGET_JAVA
 
   /*! \brief Inserts a child widget in this container at given index.
    *
@@ -294,12 +352,17 @@ public:
    */
   template <typename Widget>
     Widget *insertWidget(int index, std::unique_ptr<Widget> widget)
+#ifndef WT_TARGET_JAVA
   {
     Widget *result = widget.get();
     insertWidget(index, std::unique_ptr<WWidget>(std::move(widget)));
     return result;
   }
+#else // WT_TARGET_JAVA
+  ;
+#endif // WT_TARGET_JAVA
 
+#ifndef WT_TARGET_JAVA
   /*! \brief Creates a widget and inserts it, returning a reference to it.
    *
    * This is implemented as:
@@ -319,6 +382,9 @@ public:
     insertWidget(index, std::unique_ptr<WWidget>{std::move(w)});
     return result;
   }
+#endif // WT_TARGET_JAVA
+
+  using WWidget::removeWidget;
 
   /*! \brief Removes a child widget from this container.
    *
@@ -379,16 +445,6 @@ public:
   WFlags<AlignmentFlag> contentAlignment() const { return contentAlignment_; }
 
   /*! \brief Sets how overflow of contained children must be handled.
-   *
-   * This is an alternative (CSS-ish) way to configure scroll bars on
-   * a container widget, compared to wrapping inside a WScrollArea.
-   *
-   * Unlike WScrollArea, horizontal scrolling does not work reliably
-   * when the container widget is inserted in a layout manager: the
-   * layout manager will overflow rather than use scrollbars for this
-   * container widget. A solution then is to use WScrollArea instead.
-   *
-   * \sa WScrollArea
    */
   void setOverflow(Overflow overflow, WFlags<Orientation> orientation = 
 		   (Orientation::Horizontal | Orientation::Vertical));
@@ -445,7 +501,8 @@ public:
 
   /*! \brief return the number of pixels the container is scrolled horizontally
    *
-   *  This value is only set if setOverflow() has been called 
+   * This value is only set if setOverflow() has been called 
+   *
    * \sa setOverflow()
    * \sa scrollLeft();
    */
@@ -453,7 +510,8 @@ public:
 
   /*! \brief return the number of pixels the container is scrolled vertically
    *
-   *  This value is only set if setOverflow() has been called 
+   * This value is only set if setOverflow() has been called 
+   *
    * \sa setOverflow()
    * \sa scrollTop();
    */
@@ -486,7 +544,7 @@ private:
   std::vector<WWidget *> children_;
   std::unique_ptr<WLayout> layout_;
 
-  std::unique_ptr<std::vector<WWidget *>> addedChildren_;
+  std::unique_ptr<std::vector<WWidget *> > addedChildren_;
 
   bool globalUnfocused_;
   int scrollTop_, scrollLeft_;
