@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -239,9 +239,29 @@ public:
    *
    * This does not work when the resource is deployed at an internal path using
    * setInternalPath().
+   *
+   * \sa setInvalidAfterChanged()
    */
   void setChanged();
 
+  /*! \brief Return "page not found" for prior resource URLs after change
+   *
+   * This option invalidates earlier versions of the resource url prior to
+   * the last call of setChanged() or generateUrl(). The default value is false.
+   *
+   * This does not work when the resource is deployed at an internal path using
+   * setInternalPath().
+   *
+   * \sa setChanged(), generateUrl()
+   */
+  void setInvalidAfterChanged(bool enabled);
+
+  /*! \brief Should "page not found" be returned for outdated resource URLs
+   *
+   * \sa setInvalidAfterChanged()
+   */
+  bool invalidAfterChanged() const { return invalidAfterChanged_; }
+
   /*! \brief Sets an internal path for this resource.
    *
    * Using this method you can deploy the resource at a fixed path. Unless
@@ -274,7 +294,8 @@ public:
    * can thus be used to refer to a new "version" of the resource,
    * which can be indicated by emitting the dataChanged() signal.
    *
-   * The old urls are not invalidated by calling this method.
+   * The old urls are not invalidated by calling this method, unless
+   * you enable setInvalidAfterChanged().
    */
   const std::string& generateUrl();
 
@@ -415,6 +436,10 @@ public:
    */
   bool takesUpdateLock() const { return takesUpdateLock_; }
 
+  unsigned long version() const;
+
+  void incrementVersion();
+
 protected:
   /*! \brief Prepares the resource for deletion.
    *
@@ -448,6 +473,7 @@ private:
 
   bool trackUploadProgress_;
   bool takesUpdateLock_;
+  bool invalidAfterChanged_;
 
   std::vector<Http::ResponseContinuationPtr> continuations_;
 
@@ -462,6 +488,7 @@ private:
   ContentDisposition dispositionType_;
   std::string currentUrl_;
   std::string internalPath_;
+  unsigned long version_;
 
   WApplication *app_; // associated app (for non-static resources)
 
