@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -285,8 +285,7 @@ public:
    * contain the host part!) to a favicon, which is the icon displayed
    * in the browser for your application. Alternatively, you may
    * specify a favicon using the "favicon" property in the
-   * configuration file (see als \ref config_general "EntryPointType::Application
-   * settings (wt_config.xml)").
+   * configuration file (see also \ref config_general).
    *
    * \sa removeEntryPoint()
    */
@@ -312,8 +311,7 @@ public:
    * In a multi-threaded environment, this may only be done when the
    * server is not running.
    *
-   * When a resource has been bound to the path, the resource will not
-   * be deleted.
+   * \note If the entry point is a resource, the resource will not be deleted
    *
    * \sa addEntryPoint(), addResource()
    */
@@ -428,6 +426,16 @@ public:
    */
   WT_API std::string appRoot() const;
 
+  /*! \brief Returns the docroot (if using wthttp)
+   *
+   * If you're using wthttp, this returns the location passed to the
+   * --docroot argument, just like WApplication::docRoot(). This allows access
+   * to this parameter outside of the context of a WApplication.
+   *
+   * If you're using any other connector, this returns the empty string.
+   */
+   WTCONNECTOR_API std::string docRoot() const;
+
   /*! \brief Posts a function to a session.
    *
    * This is a thread-safe method to post a particular event
@@ -469,7 +477,15 @@ public:
    */
   WT_API void postAll(const std::function<void ()>& function);
 
-  WT_API void schedule(std::chrono::steady_clock::duration millis,
+  /*! \brief Schedules a function to be executed in a session.
+   *
+   * The \p function will run in the session specified by \p sessionId,
+   * after \p duration. If the session does not exist anymore,
+   * \p fallBackFunction will be executed.
+   *
+   * \sa post()
+   */
+  WT_API void schedule(std::chrono::steady_clock::duration duration,
 		       const std::string& sessionId,
 		       const std::function<void ()>& function,
 		       const std::function<void ()>& fallBackFunction
@@ -546,6 +562,8 @@ public:
    */
   WTCONNECTOR_API std::vector<SessionInfo> sessions() const;
 
+  void updateProcessSessionId(const std::string& sessionId);
+
   /*! \brief Returns the logger instance.
    *
    * This is the logger class used in WApplication::log() and
@@ -553,6 +571,15 @@ public:
    */
   WT_API WLogger& logger();
 
+  /*! \brief Sets a custom logger to redirect all logging to.
+   *
+   * Instead of using the server's default logger, this will send
+   * all logging to some custom WLogSink.
+   */
+  WT_API void setCustomLogger(const WLogSink &customLogger);
+
+  const WLogSink * customLogger() const;
+
   /*! \brief Adds an entry to the log.
    *
    * \sa Wt::log(), WApplication::log()
@@ -562,8 +589,11 @@ public:
   WT_API void initLogger(const std::string& logFile,
 			 const std::string& logConfig);
 
-  /*!
-   * \brief Reflects whether the current process is a dedicated session process
+  /*! \brief Reflects whether the current process is a dedicated session process
+   *
+   * \note This will only be accurate after the WServer has been configured, either
+   *       through setServerConfiguration() or one of the constructors that immediately
+   *       configures the server.
    */
   WT_API bool dedicatedSessionProcess() const;
 #endif // WT_TARGET_JAVA
@@ -592,6 +622,7 @@ private:
 
 #ifndef WT_TARGET_JAVA
   WLogger logger_;
+  const WLogSink * customLogger_;
 #endif // WT_TARGET_JAVA
 
   std::string application_, configurationFile_, appRoot_, description_;
@@ -625,6 +656,7 @@ private:
   std::function<std::string (std::size_t max_length, int purpose)> sslPasswordCallback_;
 #ifndef WT_TARGET_JAVA
   std::function<void ()> stopCallback_;
+  std::function<void (const std::string& sessionId)> updateProcessSessionIdCallback_;
 #endif // WT_TARGET_JAVA
 };
 
