@@ -14,6 +14,10 @@
 #include <Wt/Signals/signals.hpp>
 #endif // WT_TARGET_JAVA
 
+#ifdef WT_THREADED
+#include <atomic>
+#endif // WT_THREADED
+
 #include <functional>
 
 namespace Wt {
@@ -117,9 +121,6 @@ public:
    */
   virtual bool isConnected() const = 0;
 
-  void setBlocked(bool block);
-  bool isBlocked() const { return blocked_; }
-
   /*! \brief Connects to a slot.
    *
    * Every signal can be connected to a slot which does not take any
@@ -141,8 +142,6 @@ protected:
 
 private:
   SignalBase(const SignalBase& other);
-
-  bool blocked_;
 };
 
 /*
@@ -486,11 +485,15 @@ protected:
   static const int BIT_PREVENT_PROPAGATION = 5;
   static const int BIT_SIGNAL_SERVER_ANYWAY = 6;
 
-  static int nextId_;
+#ifdef WT_THREADED
+  static std::atomic<unsigned> nextId_;
+#else
+  static unsigned nextId_;
+#endif // WT_THREADED
 
   const char *name_;
   WObject *owner_;
-  const int id_;
+  const unsigned id_;
   std::vector<StatelessConnection> connections_;
   std::bitset<7> flags_;
 
@@ -894,9 +897,6 @@ EventSignal<E>::connect(WObject *target, WObject::Method method)
 template <typename E>
 void EventSignal<E>::emit(E e) const
 {
-  if (isBlocked())
-    return;
-
   processLearnedStateless();
   processNonLearnedStateless();
 
