@@ -313,7 +313,7 @@ protected:
   virtual void updateDom(DomElement& element, bool all);
   virtual bool domCanBeSaved() const;
   virtual void propagateRenderOk(bool deep = true);
-  virtual std::string renderRemoveJs(bool recursive);
+  virtual std::string renderRemoveJs(bool recursive) override;
 
   virtual void propagateSetEnabled(bool enabled) override;
   virtual void propagateSetVisible(bool visible) override;
@@ -420,6 +420,13 @@ private:
   std::unique_ptr<WLength> width_;
   std::unique_ptr<WLength> height_;
 
+  /*
+   * id_ is separate instead of in OtherImpl,
+   * because it is accessed when OtherImpl is being destroyed,
+   * from the destructor of jsScrollVisibilityChanged_
+   */
+  std::unique_ptr<std::string> id_;
+
   /*
    * Data only stored transiently, during event handling.
    */
@@ -495,7 +502,6 @@ private:
     };
 
     std::unique_ptr<std::string> elementTagName_;
-    std::unique_ptr<std::string> id_;
     std::unique_ptr<std::map<std::string, WT_USTRING> > attributes_;
     std::unique_ptr<std::vector<Member> > jsMembers_;
     std::unique_ptr<std::vector<JavaScriptStatement> > jsStatements_;
@@ -512,7 +518,7 @@ private:
 
     int scrollVisibilityMargin_;
     Signal<bool> scrollVisibilityChanged_;
-    JSignal<bool> jsScrollVisibilityChanged_;
+    std::unique_ptr<JSignal<bool> > jsScrollVisibilityChanged_;
 
     OtherImpl(WWebWidget *const self);
     ~OtherImpl();
