@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -151,7 +151,7 @@ public:
    * scheme. The widget may be shifted to the left or right by
    * specifying an offset for the \link Wt::Side::Left left\endlink or \link
    * Wt::Side::Right right\endlink) side. The widget may be shifted
-   * vertically, by specifying an offset for the \link Wt::AlignmentFlag::Top
+   * vertically, by specifying an offset for the \link Wt::Side::Top
    * top\endlink or \link Wt::Side::Bottom bottom\endlink side.
    *
    * For an \link Wt::PositionScheme::Absolute absolutely positioned\endlink widget,
@@ -392,8 +392,7 @@ public:
    *
    * This lets the widget float to one of the sides of the parent
    * widget, at the current line. A typical use is to position images
-   * within text. Valid values for Side or \if cpp Wt::None \elseif
-   * java {javadoclink Side#None None} \endif, Wt::Side::Left or Wt::Side::Right.
+   * within text. Valid values for Side Side::Left, or Side::Right.
    *
    * This applies to CSS-based layout.
    */
@@ -483,9 +482,11 @@ public:
    * visible if it and all its ancestors in the widget tree are
    * visible, which may be checked using isVisible().
    *
+   * \if cpp
    * \note hide() and show() are considered to be stateless slots by default.
    * If you override setHidden() and need to modify server state whenever it is called,
    * you'll need to call WObject::isNotStateless().
+   * \endif
    */
   virtual void setHidden(bool hidden,
 			 const WAnimation& animation = WAnimation()) = 0;
@@ -525,9 +526,11 @@ public:
    * Typically, a disabled form widget will not allow changing the
    * value, and disabled widgets will not react to mouse click events.
    *
+   * \if cpp
    * \note enable() and disable() are considered to be stateless slots by default.
    * If you override setDisabled() and need to modify server state whenever it is called,
    * you'll need to call WObject::isNotStateless().
+   * \endif
    *
    * \sa disable(), enable()
    */
@@ -748,7 +751,7 @@ public:
    *
    * The widget must actualize its contents in response.
    *
-   * \note This does *not* rerender the widget! Calling refresh() usually
+   * \note This does **not** rerender the widget! Calling refresh() usually
    *       does not have any effect (unless you've reimplemented refresh()
    *       to attach to it an effect).
    */
@@ -822,9 +825,8 @@ public:
 
   /*! \brief Loads content just before the widget is used.
    *
-   * This method is called after a widget is inserted in the widget
-   * hierarchy and fully constructed, but before the widget is rendered.
-   * Widgets that get inserted in the widget hierarchy will
+   * This function is called when a widget is inserted in the
+   * widget hierarchy. Widgets that get inserted in the widget hierarchy will
    * be rendered. Visible widgets are rendered immediately, and
    * invisible widgets in the back-ground (or not for a plain HTML
    * session). This method is called when the widget is directly or
@@ -836,7 +838,7 @@ public:
    *
    * During the life-time of a widget, this method may be called
    * multiple times, so you should make sure that you do a deferred
-   * initializiation only once.
+   * initialization only once.
    */
   virtual void load() = 0;
 
@@ -944,6 +946,13 @@ public:
    * letters, digits ([0-9]), hyphens ("-"), underscores ("_"), colons (":"),
    * and periods (".").
    *
+   * \warning We recommend that you leave the id of a widget unchanged. %Wt
+   * uses the id to identify widgets in the JavaScript it generates,
+   * and this can often leads to bugs. If you do change the id, **only** change
+   * the id right after widget construction. However, usually
+   * there's a more preferable alternative, like setting the object name
+   * (WObject::setObjectName), or adding style classes (WWidget::addStyleClass).
+   *
    * \sa WObject::id()
    */
   virtual void setId(const std::string& id) = 0;
@@ -1070,7 +1079,7 @@ public:
    *
    * This feature can be useful to implement infinite scroll, where a sentinel widget
    * placed at the bottom of the page causes more content to be loaded when it
-   * becomes visible, see the <tt>infinite-scroll</tt> example.
+   * becomes visible, see the <tt>scrollvisibility</tt> example.
    *
    * This feature can also be used to lazy load widgets when they become visible.
    *
@@ -1342,6 +1351,10 @@ protected:
 			   const std::string& declarations,
 			   const std::string& ruleName = std::string());
 
+  bool isGlobalWidget() const;
+
+  virtual std::string renderRemoveJs(bool recursive) = 0;
+
 private:
   /*
    * Booleans packed in a bitset.
@@ -1353,7 +1366,8 @@ private:
   static const int BIT_HAS_PARENT = 4;
   static const int BIT_RESIZE_AWARE = 5;
   static const int BIT_SCROLL_VISIBILITY_ENABLED = 6;
-  std::bitset<7> flags_;
+  static const int BIT_GLOBAL_WIDGET = 7;
+  std::bitset<8> flags_;
 
   EventSignalList eventSignals_;
   std::vector<EventSignalBase*> jsignals_;
@@ -1364,6 +1378,8 @@ private:
   void undoDisableEnable();
   virtual void setParentWidget(WWidget *parent);
 
+  void setGlobalWidget(bool globalWidget);
+
   virtual WWebWidget *webWidget() = 0;
 
   friend class WebRenderer;
