@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /* 
- * Copyright (C) 2011 Emweb bvba, Heverlee, Belgium
+ * Copyright (C) 2011 Emweb bv, Herent, Belgium
  *
  * See the LICENSE file for terms of use.
  */
@@ -8,14 +8,16 @@
 #ifndef HIGH_SCORES_WIDGET_H_
 #define HIGH_SCORES_WIDGET_H_
 
-#include <Wt/WContainerWidget>
+#include <Wt/WContainerWidget.h>
+
+using namespace Wt;
 
 class Session;
 
-class HighScoresWidget: public Wt::WContainerWidget
+class HighScoresWidget: public WContainerWidget
 {
 public:
-  HighScoresWidget(Session *session, Wt::WContainerWidget *parent = 0);
+  HighScoresWidget(Session *session);
   void update();
 
 private:
